Schemas
=====================

Submodules
----------

.. toctree::
   :maxdepth: 2

   genai.schemas.descriptions
   genai.schemas.generate_params
   genai.schemas.history_params
   genai.schemas.responses
   genai.schemas.token_params
   genai.schemas.tunes_params
   genai.schemas.files_params
